@@ -21,7 +21,7 @@ gi.require_version('XApp', '1.0')
 from gi.repository import Gtk, Gdk, Gio, XApp, GdkPixbuf
 
 #   3. Local application/library specific imports.
-from common import _async, idle, WebAppManager, download_favicon, ICONS_DIR, BROWSER_TYPE_FIREFOX
+from common import _async, idle, WebAppManager, download_favicon, ICONS_DIR, BROWSER_TYPE_FIREFOX, BROWSER_TYPE_FIREFOX_FLATPAK
 
 setproctitle.setproctitle("webapp-manager")
 
@@ -452,7 +452,7 @@ class WebAppManagerWindow:
 
     def show_hide_browser_widgets(self):
         browser = self.browser_combo.get_model()[self.browser_combo.get_active()][BROWSER_OBJ]
-        if browser.browser_type == BROWSER_TYPE_FIREFOX:
+        if browser.browser_type == BROWSER_TYPE_FIREFOX or browser.browser_type == BROWSER_TYPE_FIREFOX_FLATPAK:
             self.isolated_label.hide()
             self.isolated_switch.hide()
             self.navbar_label.show()
